/* gates.c
 *
 * by John Pavan
 *
 * functions for reading in and assigning gate information
 * for use with sorting
 */

/* --- includes --- */

#include "gates.h"
#include <stdio.h>

/* --- structs --- */

/* --- globals --- */

int num_gammagates;
struct gamma_gte *gammagates;
int num_axes;
struct axis_info *axes;
int num_gate_arrays;
struct gate_array *gatearrays;
int num_gammagate_arrays;
struct gate_array *gammagatearrays;

/* --- function declarations --- */

void ReadDetectorGte2(char *sFilename);
void ReadGammaGte2(char *sFilename);
void MakeGateArrays2(int type);

/* --- functions --- */

/* ReadDetectorGte
 *
 * Reads in detector information from a file and then makes 
 * the appropriate gate arrays
 */
void ReadDetectorGte2(char *sFilename)
{
  FILE *infile;
  int i,j,k,test,vals;
  int keepreading;

  if ((infile = fopen(sFilename,"r")) != NULL) {
    keepreading = 1;
    num_axes = 0;
    if (axes != NULL) {
      free(axes);
      axes = NULL;
    }
    while (keepreading) {
      test = fscanf(infile,"%d",&vals);
      if (test != 1) {
	GetMessageDialog("Error reading the gte file");
	break;
      }
      if (vals > 0) { // we have something to read
	num_axes++;
	if (axes = NULL) { // if this is the first one
	  axes = (struct axis_info *) malloc(sizeof(struct axis_info));
	} else { // all other cases
	  axes = (struct axis_info *) realloc(axes,num_axes * 
					      sizeof(struct axis_info));
	} // now memory is allocated
	axes[num_axes - 1].num = vals;
	axes[num_axes - 1].detectors = (short unsigned int *) 
	  malloc(vals * sizeof(short unsigned int));
	for (j = 0; j < vals; j) {
	  test = fscanf(infile,"%d,%d,%d,%d,%d,%d,%d,%d,%d,%d",
			&tempints[0],&tempints[1],&tempints[2],
			&tempints[3],&tempints[4],&tempints[5],
			&tempints[6],&tempints[7],&tempints[8],
			&tempints[9]);
	  for ( k = 0; k < test; k++) {
	    if (j+k < vals) { // to be safe
	      axes[num_axes - 1].detectors[j+k] = tempints[k]; 
	    }
	  }
	  j = j + test;
	}
      }  else keepreading = 0; // done reading the first one
    } // end of loop
    fclose(infile);
  }
}
